@@ -41,19 +41,17 @@
 
 #include <QDragEnterEvent>
 #include <QDragMoveEvent>
-#include <QPointer>
+#include <QWeakPointer>
 
 static bool isValidArchiveDrag(const QMimeData *data)
 {
-    return
-        data->hasUrls() &&
-        data->urls().count() == 1;
+    return ((data->hasUrls()) && (data->urls().count() == 1));
 }
 
 MainWindow::MainWindow(QWidget *)
         : KParts::MainWindow()
 {
-    setXMLFile("arkui.rc");
+    setXMLFile(QLatin1String( "arkui.rc" ));
 
     setupActions();
     statusBar();
@@ -61,7 +59,7 @@ MainWindow::MainWindow(QWidget *)
     if (!initialGeometrySet()) {
         resize(640, 480);
     }
-    setAutoSaveSettings("MainWindow");
+    setAutoSaveSettings(QLatin1String( "MainWindow" ));
 
     setAcceptDrops(true);
 }
@@ -80,11 +78,14 @@ void MainWindow::dragEnterEvent(QDragEnterEvent * event)
     kDebug() << event;
 
     Interface *iface = qobject_cast<Interface*>(m_part);
-    if (iface->isBusy()) return;
+    if (iface->isBusy()) {
+        return;
+    }
 
-    if (event->source() == NULL &&
-            isValidArchiveDrag(event->mimeData()))
+    if ((event->source() == NULL) &&
+        (isValidArchiveDrag(event->mimeData()))) {
         event->acceptProposedAction();
+    }
     return;
 }
 
@@ -93,11 +94,14 @@ void MainWindow::dropEvent(QDropEvent * event)
     kDebug() << event;
 
     Interface *iface = qobject_cast<Interface*>(m_part);
-    if (iface->isBusy()) return;
+    if (iface->isBusy()) {
+        return;
+    }
 
-    if (event->source() == NULL &&
-            isValidArchiveDrag(event->mimeData()))
+    if ((event->source() == NULL) &&
+        (isValidArchiveDrag(event->mimeData()))) {
         event->acceptProposedAction();
+    }
 
     //TODO: if this call provokes a message box the drag will still be going
     //while the box is onscreen. looks buggy, do something about it
@@ -109,16 +113,19 @@ void MainWindow::dragMoveEvent(QDragMoveEvent * event)
     kDebug() << event;
 
     Interface *iface = qobject_cast<Interface*>(m_part);
-    if (iface->isBusy()) return;
+    if (iface->isBusy()) {
+        return;
+    }
 
-    if (event->source() == NULL &&
-            isValidArchiveDrag(event->mimeData()))
+    if ((event->source() == NULL) &&
+        (isValidArchiveDrag(event->mimeData()))) {
         event->acceptProposedAction();
+    }
 }
 
 bool MainWindow::loadPart()
 {
-    KPluginFactory *factory = KPluginLoader("arkpart").factory();
+    KPluginFactory *factory = KPluginLoader(QLatin1String( "arkpart" )).factory();
     if (factory) {
         m_part = static_cast<KParts::ReadWritePart*>(factory->create<KParts::ReadWritePart>(this));
     }
@@ -127,7 +134,7 @@ bool MainWindow::loadPart()
         return false;
     }
 
-    m_part->setObjectName("ArkPart");
+    m_part->setObjectName( QLatin1String("ArkPart" ));
     setCentralWidget(m_part->widget());
     createGUI(m_part);
 
@@ -181,22 +188,22 @@ void MainWindow::editToolbars()
 {
     saveMainWindowSettings(KGlobal::config()->group(QLatin1String("MainWindow")));
 
-    QPointer<KEditToolBar> dlg = new KEditToolBar(factory(), this);
-    dlg->exec();
+    QWeakPointer<KEditToolBar> dlg = new KEditToolBar(factory(), this);
+    dlg.data()->exec();
 
     createGUI(m_part);
 
     applyMainWindowSettings(KGlobal::config()->group(QLatin1String("MainWindow")));
 
-    delete dlg;
+    delete dlg.data();
 }
 
 void MainWindow::openArchive()
 {
     Interface *iface = qobject_cast<Interface*>(m_part);
     Q_ASSERT(iface);
-    KUrl url = KFileDialog::getOpenUrl(KUrl("kfiledialog:///ArkOpenDir"),
-                                       Kerfuffle::supportedMimeTypes().join(" "),
+    const KUrl url = KFileDialog::getOpenUrl(KUrl("kfiledialog:///ArkOpenDir"),
+                                       Kerfuffle::supportedMimeTypes().join( QLatin1String( " " )),
                                        this);
     openUrl(url);
 }
@@ -217,9 +224,9 @@ void MainWindow::openUrl(const KUrl& url)
 void MainWindow::setShowExtractDialog(bool option)
 {
     if (option) {
-        m_openArgs.metaData()["showExtractDialog"] = "true";
+        m_openArgs.metaData()[QLatin1String( "showExtractDialog" )] = QLatin1String( "true" );
     } else {
-        m_openArgs.metaData().remove("showExtractDialog");
+        m_openArgs.metaData().remove(QLatin1String( "showExtractDialog" ));
     }
 }
 
@@ -232,17 +239,19 @@ void MainWindow::newArchive()
 {
     Interface *iface = qobject_cast<Interface*>(m_part);
     Q_ASSERT(iface);
-    QStringList mimeTypes = Kerfuffle::supportedWriteMimeTypes();
 
-    kDebug() << "Supported mimetypes are" << mimeTypes.join(" ");
+    const QStringList mimeTypes = Kerfuffle::supportedWriteMimeTypes();
 
-    QString saveFile = KFileDialog::getSaveFileName(KUrl("kfiledialog:///ArkNewDir"),
-                       mimeTypes.join(" "));
+    kDebug() << "Supported mimetypes are" << mimeTypes.join( QLatin1String( " " ));
 
-    m_openArgs.metaData()["createNewArchive"] = "true";
+    const KUrl saveFileUrl =
+        KFileDialog::getSaveUrl(KUrl("kfiledialog:///ArkNewDir"),
+                                mimeTypes.join(QLatin1String(" ")));
 
-    openUrl(KUrl(saveFile));
+    m_openArgs.metaData()[QLatin1String( "createNewArchive" )] = QLatin1String( "true" );
 
-    m_openArgs.metaData().remove("showExtractDialog");
-    m_openArgs.metaData().remove("createNewArchive");
+    openUrl(saveFileUrl);
+
+    m_openArgs.metaData().remove(QLatin1String( "showExtractDialog" ));
+    m_openArgs.metaData().remove(QLatin1String( "createNewArchive" ));
 }
