@@ -58,7 +58,7 @@ ExtractionDialog::ExtractionDialog(QWidget *parent)
 
     mainWidget()->layout()->addWidget(m_ui);
     setCaption(i18nc("@title:window", "Extract"));
-    m_ui->iconLabel->setPixmap(DesktopIcon("archive-extract"));
+    m_ui->iconLabel->setPixmap(DesktopIcon(QLatin1String( "archive-extract" )));
 
     m_ui->filesToExtractGroupBox->hide();
     m_ui->allFilesButton->setChecked(true);
@@ -96,7 +96,7 @@ void ExtractionDialog::batchModeOption()
 void ExtractionDialog::accept()
 {
     if (extractToSubfolder()) {
-        if (subfolder().contains("/")) {
+        if (subfolder().contains(QLatin1String( "/" ))) {
             KMessageBox::error(NULL, i18n("The subfolder name may not contain the character '/'."));
             return;
         }
@@ -105,7 +105,7 @@ void ExtractionDialog::accept()
 
         if (KIO::NetAccess::exists(pathWithSubfolder, KIO::NetAccess::SourceSide, 0)) {
             if (QFileInfo(pathWithSubfolder).isDir()) {
-                int overwrite = KMessageBox::questionYesNo(0, i18n("The folder '%1' already exists. Are you sure you want to extract here?", pathWithSubfolder), i18n("Folder exists"), KGuiItem(i18n("Extract here")), KGuiItem(i18n("Cancel")));
+                int overwrite = KMessageBox::questionYesNo(0, i18nc("@info", "The folder <filename>%1</filename> already exists. Are you sure you want to extract here?", pathWithSubfolder), i18n("Folder exists"), KGuiItem(i18n("Extract here")), KGuiItem(i18n("Cancel")));
 
                 if (overwrite == KMessageBox::No) {
                     //TODO: choosing retry should also be possible, so one does
@@ -114,13 +114,13 @@ void ExtractionDialog::accept()
                 }
             } else {
                 KMessageBox::detailedError(0,
-                                           i18n("The folder <b>%1</b> could not be created.", subfolder()),
-                                           i18n("<b>%1</b> already exists, but is not a folder.", subfolder()));
+                                           i18nc("@info", "The folder <filename>%1</filename> could not be created.", subfolder()),
+                                           i18nc("@info", "<filename>%1</filename> already exists, but is not a folder.", subfolder()));
                 return;
             }
         } else if (!KIO::NetAccess::mkdir(pathWithSubfolder, 0)) {
             KMessageBox::detailedError(0,
-                                       i18n("The folder <b>%1</b> could not be created.", subfolder()),
+                                       i18nc("@info", "The folder <filename>%1</filename> could not be created.", subfolder()),
                                        i18n("Please check your permissions to create it."));
             return;
         }
@@ -211,7 +211,7 @@ bool ExtractionDialog::closeAfterExtraction() const
 KUrl ExtractionDialog::destinationDirectory() const
 {
     if (extractToSubfolder()) {
-        return url().pathOrUrl(KUrl::AddTrailingSlash) + subfolder() + '/';
+        return url().pathOrUrl(KUrl::AddTrailingSlash) + subfolder() + QLatin1Char( '/' );
     } else {
         return url().pathOrUrl(KUrl::AddTrailingSlash);
     }
