@@ -60,8 +60,10 @@ public:
 
     static bool compareAscending(const QPair<ArchiveNode*,int> &a, const QPair<ArchiveNode*,int> &b) {
         // #234373: sort folders before files
-        if (a.first->isDir() != b.first->isDir()) {
-            return a.first->isDir();
+        if ((a.first->isDir()) && (!b.first->isDir())) {
+            return true;
+        } else if ((!a.first->isDir()) && (b.first->isDir())) {
+            return false;
         }
 
         if (currentSortColumn == FileName) {
@@ -76,8 +78,10 @@ public:
 
     static bool compareDescending(const QPair<ArchiveNode*,int> &a, const QPair<ArchiveNode*,int> &b) {
         // #234373: sort folders before files
-        if (a.first->isDir() != b.first->isDir()) {
-            return !(a.first->isDir());
+        if ((a.first->isDir()) && (!b.first->isDir())) {
+            return true;
+        } else if ((!a.first->isDir()) && (b.first->isDir())) {
+            return false;
         }
 
         if (currentSortColumn == FileName) {
@@ -435,9 +439,9 @@ void ArchiveModel::sort(int column, Qt::SortOrder order)
         }
 
         if (order == Qt::AscendingOrder) {
-            qSort(sorting.begin(), sorting.end(), ArchiveNode::compareAscending);
+            qStableSort(sorting.begin(), sorting.end(), ArchiveNode::compareAscending);
         } else {
-            qSort(sorting.begin(), sorting.end(), ArchiveNode::compareDescending);
+            qStableSort(sorting.begin(), sorting.end(), ArchiveNode::compareDescending);
         }
 
         QModelIndexList fromIndexes;
@@ -480,28 +484,15 @@ QStringList ArchiveModel::mimeTypes() const
 QMimeData * ArchiveModel::mimeData(const QModelIndexList & indexes) const
 {
     kDebug();
-    //prepare the fallback kio_slave filenames
     QStringList files;
-    bool noFallback = false;
 
     QString archiveName = m_archive->fileName();
-    QString ext = QFileInfo(archiveName).suffix().toUpper();
-    if (ext == QLatin1String( "TAR" )) {
-        archiveName.prepend(QLatin1String( "tar:" ));
-    } else if (ext == QLatin1String( "ZIP" )) {
-        archiveName.prepend(QLatin1String( "zip:" ));
-    } else if (archiveName.right(6).toUpper() == QLatin1String( "TAR.GZ" )) {
-        archiveName.prepend(QLatin1String( "tar:" ));
-    } else
-        noFallback = true;
-
-    if (!archiveName.endsWith(QLatin1Char( '/' ))) {
-        archiveName.append(QLatin1Char( '/' ));
+    if (!archiveName.endsWith(QLatin1Char('/'))) {
+        archiveName.append(QLatin1Char('/'));
     }
 
     //Populate the internal list of files
     foreach(const QModelIndex &index, indexes) {
-
         //to limit only one index per row
         if (index.column() != 0) {
             continue;
@@ -511,18 +502,12 @@ QMimeData * ArchiveModel::mimeData(const QModelIndexList & indexes) const
         files << file;
     }
 
-    KUrl::List kiolist(files);
-
     //prepare the dbus-based drag/drop mimedata
     QMimeData *data = new QMimeData();
-    data->setData(QLatin1String( "application/x-kde-dndextract" ),
+    data->setData(QLatin1String("application/x-kde-dndextract"),
                   QDBusConnection::sessionBus().baseService().toUtf8()
                  );
 
-
-    if (!noFallback) {
-        kiolist.populateMimeData(data);
-    }
     return data;
 }
 
@@ -568,16 +553,14 @@ bool ArchiveModel::dropMimeData(const QMimeData * data, Qt::DropAction action, i
 // For a rationale, see bugs #194241 and #241967
 QString ArchiveModel::cleanFileName(const QString& fileName)
 {
-    QString cleanName(fileName);
-
-    if ((cleanName == QLatin1String("/")) ||
-        (cleanName == QLatin1String("."))) { // "." is present in ISO files
-        cleanName.clear();
-    } else if (cleanName.startsWith(QLatin1String("./"))) {
-        cleanName.remove(0, 2);
+    if ((fileName == QLatin1String("/")) ||
+        (fileName == QLatin1String("."))) { // "." is present in ISO files
+        return QString();
+    } else if (fileName.startsWith(QLatin1String("./"))) {
+        return fileName.mid(2);
     }
 
-    return cleanName;
+    return fileName;
 }
 
 ArchiveDirNode* ArchiveModel::parentFor(const ArchiveEntry& entry)
