@@ -45,6 +45,18 @@ CliPlugin::~CliPlugin()
 {
 }
 
+// #272281: the proprietary unrar program does not like trailing '/'s
+//          in directories passed to it when extracting only part of
+//          the files in an archive.
+QString CliPlugin::escapeFileName(const QString &fileName) const
+{
+    if (fileName.endsWith(QLatin1Char('/'))) {
+        return fileName.left(fileName.length() - 1);
+    }
+
+    return fileName;
+}
+
 ParameterList CliPlugin::parameterList() const
 {
     static ParameterList p;
@@ -78,6 +90,8 @@ ParameterList CliPlugin::parameterList() const
 
         p[AddArgs] = QStringList() << QLatin1String( "a" ) << QLatin1String( "$Archive" ) << QLatin1String( "$Files" );
 
+        p[PasswordPromptPattern] = QLatin1String("Enter password \\(will not be echoed\\) for");
+
         p[WrongPasswordPatterns] = QStringList() << QLatin1String("password incorrect") << QLatin1String("wrong password");
         p[ExtractionFailedPatterns] = QStringList() << QLatin1String( "CRC failed" ) << QLatin1String( "Cannot find volume" );
     }
