@@ -23,13 +23,12 @@
  */
 
 
-#ifndef _D_KCALCDISPLAY_H_
-#define _D_KCALCDISPLAY_H_
+#ifndef KCALCDISPLAY_H_
+#define KCALCDISPLAY_H_
 
 #include <QFrame>
 #include <QVector>
 #include "knumber.h"
-#include "kcalctype.h"
 
 class CalcEngine;
 class KAction;
@@ -72,41 +71,41 @@ public:
 
     enum Event {
         EventReset, // resets display
-        EventClear, // if no _error reset display
+        EventClear, // if no error reset display
         EventError,
         EventChangeSign
     };
 
-    bool sendEvent(Event const event);
-    void deleteLastDigit(void);
-    KNumber const & getAmount(void) const;
-    void newCharacter(char const new_char);
-    bool setAmount(KNumber const & new_amount);
+    bool sendEvent(Event event);
+    void deleteLastDigit();
+    const KNumber &getAmount() const;
+    void newCharacter(char new_char);
+    bool setAmount(const KNumber &new_amount);
     int setBase(NumBase new_base);
     void setBeep(bool flag);
     void setGroupDigits(bool flag);
     void setTwosComplement(bool flag);
     void setFixedPrecision(int precision);
     void setPrecision(int precision);
-    void setText(QString const &string);
+    void setText(const QString &string);
     QString text() const;
-    bool updateDisplay(void);
-    void setStatusText(int i, const QString& text);
+    bool updateDisplay();
+    void setStatusText(int i, const QString &text);
     virtual QSize sizeHint() const;
 
     void changeSettings();
     void enterDigit(int data);
-    void updateFromCore(CalcEngine const &core,
+    void updateFromCore(const CalcEngine &core,
                         bool store_result_in_history = false);
 
 public slots:
-    void slotCut(void);
-    void slotCopy(void);
+    void slotCut();
+    void slotCopy();
     void slotPaste(bool bClipboard = true);
 
 signals:
-    void clicked(void);
-    void changedText(QString const &);
+    void clicked();
+    void changedText(const QString &);
     void changedAmount(const KNumber &);
 
 protected:
@@ -114,42 +113,42 @@ protected:
     virtual void paintEvent(QPaintEvent *p);
 
 private:
-    bool changeSign(void);
-    void invertColors(void);
+    bool changeSign();
+    void invertColors();
     void initStyleOption(QStyleOptionFrame *option) const;
 
 private slots:
-    void slotSelectionTimedOut(void);
-    void slotDisplaySelected(void);
-    void slotHistoryBack(void);
-    void slotHistoryForward(void);
+    void slotSelectionTimedOut();
+    void slotDisplaySelected();
+    void slotHistoryBack();
+    void slotHistoryForward();
 
 private:
-    QString _text;
-    bool _beep;
-    bool _groupdigits;
-    bool _twoscomplement;
-    int  _button;
-    bool _lit;
-    NumBase _num_base;
+    QString text_;
+    bool beep_;
+    bool groupdigits_;
+    bool twoscomplement_;
+    int  button_;
+    bool lit_;
+    NumBase num_base_;
 
-    int _precision;
-    int _fixed_precision; // "-1" = no fixed_precision
+    int precision_;
+    int fixed_precision_; // "-1" = no fixed_precision
 
-    KNumber _display_amount;
+    KNumber display_amount_;
 
-    QVector<KNumber> _history_list;
-    int _history_index;
+    QVector<KNumber> history_list_;
+    int history_index_;
 
     // only used for input of new numbers
-    bool _eestate;
-    bool _period;
-    bool _neg_sign;
-    QString _str_int;
-    QString _str_int_exp;
-    QString _str_status[NUM_STATUS_TEXT];
+    bool eestate_;
+    bool period_;
+    bool neg_sign_;
+    QString str_int_;
+    QString str_int_exp_;
+    QString str_status_[NUM_STATUS_TEXT];
 
-    QTimer* _selection_timer;
+    QTimer* selection_timer_;
 };
 
-#endif // _KCALCDISPLAY_H_
+#endif // KCALCDISPLAY_H_
