@@ -1,5 +1,5 @@
 /*
-    $Id: stats.cpp 1125481 2010-05-11 14:19:05Z eikekrumbacher $
+    $Id: stats.cpp 1188797 2010-10-23 05:06:19Z teran $
 
     KCalc, a scientific calculator for the X window system using the
     Qt widget libraries, available at no cost at http://www.troll.no
@@ -26,12 +26,11 @@
 
 #include "stats.h"
 #ifdef DEBUG_STATS
-#include <stdio.h>
+#include <cstdio>
 #endif
 
-KStats::KStats()
+KStats::KStats() : error_flag_(false)
 {
-    error_flag = false;
 }
 
 KStats::~KStats()
@@ -40,39 +39,38 @@ KStats::~KStats()
 
 void KStats::clearAll()
 {
-    mData.clear();
+    data_.clear();
 }
 
-void KStats::enterData(KNumber const & _data)
+void KStats::enterData(const KNumber &data)
 {
 
-    mData.push_back(_data);
+    data_.push_back(data);
 #ifdef DEBUG_STATS
-    printf("Added %Lg\n", _data);
-    printf("count %d\n", mData.size());
+    printf("Added %Lg\n", data);
+    printf("count %d\n", data.size());
 #endif
 
 }
 
 
-void KStats::clearLast(void)
+void KStats::clearLast()
 {
 
-    mData.pop_back();
+    data_.pop_back();
 #ifdef DEBUG_STATS
-    printf("count %d\n", mData.size());
+    printf("count %d\n", data_.size());
 #endif
 
 
 }
 
-KNumber KStats::sum(void)
+KNumber KStats::sum()
 {
 
     KNumber result = 0;
-    QVector<KNumber>::iterator p;
-
-    for (p = mData.begin(); p != mData.end(); ++p) {
+	
+    for (QVector<KNumber>::const_iterator p = data_.constBegin(); p != data_.constEnd(); ++p) {
         result += *p;
     }
 
@@ -83,7 +81,7 @@ KNumber KStats::sum(void)
     return result;
 }
 
-KNumber KStats::median(void)
+KNumber KStats::median()
 {
 
     KNumber result = 0;
@@ -93,39 +91,38 @@ KNumber KStats::median(void)
     bound = count();
 
     if (bound == 0) {
-        error_flag = true;
+        error_flag_ = true;
         return 0;
     }
 
     if (bound == 1)
-        return mData.at(0);
+        return data_.at(0);
 
-    // need to copy mData-list, because sorting afterwards
-    QVector<KNumber> tmp_mData(mData);
-    qSort(tmp_mData);
+    // need to copy data_-list, because sorting afterwards
+    QVector<KNumber> tmp_data(data_);
+    qSort(tmp_data);
 
     if (bound & 1) {    // odd
         index = (bound - 1) / 2 + 1;
-        result =  tmp_mData.at(index - 1);
+        result =  tmp_data.at(index - 1);
     } else { // even
         index = bound / 2;
-        result = ((tmp_mData.at(index - 1))  + (tmp_mData.at(index))) / KNumber(2);
+        result = ((tmp_data.at(index - 1))  + (tmp_data.at(index))) / KNumber(2);
     }
 
     return result;
 }
 
 
-KNumber KStats::std_kernel(void)
+KNumber KStats::std_kernel()
 {
     KNumber result = KNumber::Zero;
-    KNumber _mean;
-    QVector<KNumber>::iterator p;
+    KNumber mean_value;
 
-    _mean = mean();
+    mean_value = mean();
 
-    for (p = mData.begin(); p != mData.end(); ++p) {
-        result += (*p - _mean) * (*p - _mean);
+    for (QVector<KNumber>::const_iterator p = data_.constBegin(); p != data_.constEnd(); ++p) {
+        result += (*p - mean_value) * (*p - mean_value);
     }
 
     return result;
@@ -136,9 +133,8 @@ KNumber KStats::sum_of_squares()
 {
 
     KNumber result = 0;
-    QVector<KNumber>::iterator p;
 
-    for (p = mData.begin(); p != mData.end(); ++p) {
+    for (QVector<KNumber>::const_iterator p = data_.constBegin(); p != data_.constEnd(); ++p) {
         result += ((*p) * (*p));
     }
 
@@ -146,10 +142,10 @@ KNumber KStats::sum_of_squares()
 }
 
 
-KNumber KStats::mean(void)
+KNumber KStats::mean()
 {
     if (count() == 0) {
-        error_flag = true;
+        error_flag_ = true;
         return 0;
     }
 
@@ -157,10 +153,10 @@ KNumber KStats::mean(void)
 }
 
 
-KNumber KStats::std(void)
+KNumber KStats::std()
 {
     if (count() == 0) {
-        error_flag = true;
+        error_flag_ = true;
         return KNumber::Zero;
     }
 
@@ -168,12 +164,12 @@ KNumber KStats::std(void)
 }
 
 
-KNumber KStats::sample_std(void)
+KNumber KStats::sample_std()
 {
     KNumber result = 0;
 
     if (count() < 2) {
-        error_flag = true;
+        error_flag_ = true;
         return KNumber::Zero;
     }
 
@@ -188,17 +184,17 @@ KNumber KStats::sample_std(void)
 }
 
 
-int KStats::count(void) const
+int KStats::count() const
 {
-    return static_cast<int>(mData.size());
+    return data_.size();
 }
 
 
 bool KStats::error()
 {
 
-    bool value = error_flag;
-    error_flag = false;
+    bool value = error_flag_;
+    error_flag_ = false;
     return value;
 }
 
