@@ -1,5 +1,5 @@
 /*
-    $Id: stats.h 1125481 2010-05-11 14:19:05Z eikekrumbacher $
+    $Id: stats.h 1171786 2010-09-05 05:58:17Z teran $
 
     KCalc, a scientific calculator for the X window system using the
     Qt widget libraries, available at no cost at http://www.troll.no
@@ -23,8 +23,8 @@
 
 */
 
-#ifndef KSTATS_H
-#define KSTATS_H
+#ifndef KSTATS_H_
+#define KSTATS_H_
 
 #include <QVector>
 #include "knumber.h"
@@ -38,7 +38,7 @@ public:
 
 public:
     void clearAll();
-    void enterData(const KNumber & data);
+    void enterData(const KNumber &data);
     void clearLast();
     KNumber sum();
     KNumber sum_of_squares();
@@ -51,11 +51,11 @@ public:
     bool     error();
 
 private:
-    QVector<KNumber> mData;
-    bool error_flag;
+    QVector<KNumber> data_;
+    bool error_flag_;
 
 };
 
 
-#endif /*KSTATS_H*/
+#endif // KSTATS_H_
 
