@@ -39,9 +39,9 @@ static QString extPath = QString();
 {
 	if (extPath.isEmpty())
 	{
-		QString path = getenv("PATH");
-		if (!path.isEmpty()) path.append(":");
-		path.append("/usr/sbin:/sbin");
+            QString path = QLatin1String( qgetenv("PATH") );
+		if (!path.isEmpty()) path.append(QLatin1String( ":" ));
+		path.append(QLatin1String( "/usr/sbin:/sbin" ));
 		extPath = path;
 	}
 
@@ -113,10 +113,10 @@ void KFActionQueue::queue(KFAction *p)
 
 	if (p)
 	{
-		if (d->list.first()==p)
+		if (!d->list.isEmpty() && d->list.first()==p)
 		{
 			d->list.removeFirst();
-			// delete p;           /* auto-delete */
+			delete p;
 		}
 		else
 		{
@@ -137,7 +137,7 @@ void KFActionQueue::queue(KFAction *p)
 		return;
 	}
 
-	KFAction *next = d->list.first();
+	KFAction *next = d->list.isEmpty() ? 0 : d->list.first();
 	if (!next)
 	{
 		emit done(this,true);
@@ -162,25 +162,25 @@ void KFActionQueue::queue(KFAction *p)
 //
 #ifdef ANY_LINUX
 
-const char *fd0H1440[] = { "/dev/fd0u1440", "/dev/floppy/0u1440", "/dev/fd0h1440", "/dev/fd0H1440", 0L } ;
-const char *fd0D720[] = { "/dev/fd0u720", "/dev/floppy/0u720", "/dev/fd0D720", "/dev/fd0h720", 0L };
-const char *fd0h1200[] = { "/dev/fd0h1200", "/dev/floppy/0h1200", 0L };
-const char *fd0h360[] = { "/dev/fd0u360", "/dev/floppy/0u360", "/dev/fd0h360", "/dev/fd0d360", 0L };
+const char * const fd0H1440[] = { "/dev/fd0u1440", "/dev/floppy/0u1440", "/dev/fd0h1440", "/dev/fd0H1440", 0L } ;
+const char * const fd0D720[] = { "/dev/fd0u720", "/dev/floppy/0u720", "/dev/fd0D720", "/dev/fd0h720", 0L };
+const char * const fd0h1200[] = { "/dev/fd0h1200", "/dev/floppy/0h1200", 0L };
+const char * const fd0h360[] = { "/dev/fd0u360", "/dev/floppy/0u360", "/dev/fd0h360", "/dev/fd0d360", 0L };
 
-const char *fd1H1440[] = { "/dev/fd1u1440", "/dev/floppy/1u1440","/dev/fd1h1440", "/dev/fd1H1440", 0L } ;
-const char *fd1D720[] = { "/dev/fd1u720", "/dev/floppy/1u720", "/dev/fd1D720", "/dev/fd1h720", 0L };
-const char *fd1h1200[] = { "/dev/fd1h1200", "/dev/floppy/1h1200", 0L };
-const char *fd1h360[] = { "/dev/fd1u360", "/dev/floppy/1u360","/dev/fd1h360", "/dev/fd1d360", 0L };
+const char * const fd1H1440[] = { "/dev/fd1u1440", "/dev/floppy/1u1440","/dev/fd1h1440", "/dev/fd1H1440", 0L } ;
+const char * const fd1D720[] = { "/dev/fd1u720", "/dev/floppy/1u720", "/dev/fd1D720", "/dev/fd1h720", 0L };
+const char * const fd1h1200[] = { "/dev/fd1h1200", "/dev/floppy/1h1200", 0L };
+const char * const fd1h360[] = { "/dev/fd1u360", "/dev/floppy/1u360","/dev/fd1h360", "/dev/fd1d360", 0L };
 
-const char *fd0auto[] = { "/dev/fd0", 0L };
-const char *fd1auto[] = { "/dev/fd1", 0L };
+const char * const fd0auto[] = { "/dev/fd0", 0L };
+const char * const fd1auto[] = { "/dev/fd1", 0L };
 
 #endif
 
 
 #ifdef ANY_BSD
-const char *fd0[] = { "/dev/fd0", 0L } ;
-const char *fd1[] = { "/dev/fd1", 0L } ;
+const char * const fd0[] = { "/dev/fd0", 0L } ;
+const char * const fd1[] = { "/dev/fd1", 0L } ;
 #endif
 
 // Next we have a table of device names and characteristics.
@@ -196,7 +196,7 @@ const char *fd1[] = { "/dev/fd1", 0L } ;
 // The flags field is unused in this implementation.
 //
 //
-fdinfo fdtable[] =
+const fdinfo fdtable[] =
 {
 #ifdef ANY_LINUX
         // device  drv blks trk flg
@@ -259,7 +259,7 @@ bool FloppyAction::configureDevice(int drive,int density)
 	const char *devicename = 0L;
 
 	deviceInfo=0L;
-	deviceName = QString();
+	deviceName.clear();
 
 	if ((drive<0) || (drive>1))
 	{
@@ -267,7 +267,7 @@ bool FloppyAction::configureDevice(int drive,int density)
 		return false;
 	}
 
-	fdinfo *deviceinfo = fdtable;
+	const fdinfo *deviceinfo = fdtable;
 	for ( ; deviceinfo && (deviceinfo->devices) ; deviceinfo++)
 	{
 		if (deviceinfo->blocks != density)
@@ -295,7 +295,7 @@ bool FloppyAction::configureDevice(int drive,int density)
 		return false;
 	}
 
-	for (const char **devices=deviceinfo->devices ;
+	for (const char* const* devices=deviceinfo->devices ;
 		*devices ; devices++)
 	{
 		if (access(*devices,W_OK)>=0)
@@ -310,12 +310,12 @@ bool FloppyAction::configureDevice(int drive,int density)
 	{
 		const QString str = i18n(
 			"Cannot access %1\nMake sure that the device exists and that "
-			"you have write permission to it.", deviceinfo->devices[0]);
+			"you have write permission to it.",QLatin1String( deviceinfo->devices[0] ));
 		emit status(str,-1);
 		return false;
 	}
 
-	deviceName = devicename;
+	deviceName = QLatin1String( devicename );
 	deviceInfo = deviceinfo;
 
 	return true;
@@ -374,7 +374,7 @@ bool FloppyAction::startProcess()
 	connect(theProcess,SIGNAL(receivedStderr(K3Process *,char *,int)),
 		this,SLOT(processStdErr(K3Process *,char *,int)));
 
-        theProcess->setEnvironment( "LC_ALL", "C" ); // We need the untranslated output of the tool
+        theProcess->setEnvironment( QLatin1String( "LC_ALL" ), QLatin1String( "C" ) ); // We need the untranslated output of the tool
 	return theProcess->start(K3Process::NotifyOnExit,
 		K3Process::AllOutput);
 }
@@ -388,12 +388,12 @@ FDFormat::FDFormat(QObject *p) :
 {
 	DEBUGSETUP;
 	theProcessName = QString::fromLatin1("fdformat");
-	setObjectName("FDFormat");
+	setObjectName( QLatin1String("FDFormat" ));
 }
 
 /* static */ bool FDFormat::runtimeCheck()
 {
-	fdformatName = findExecutable("fdformat");
+	fdformatName = findExecutable(QLatin1String( "fdformat" ));
 	return (!fdformatName.isEmpty());
 }
 
@@ -421,7 +421,7 @@ bool FDFormat::configure(bool v)
 		return;
 	}
 
-	if (theProcess) delete theProcess;
+	delete theProcess;
 	theProcess = new K3Process;
 
 	formatTrackCount=0;
@@ -431,13 +431,13 @@ bool FDFormat::configure(bool v)
 	// Common to Linux and BSD, others may differ
 	if (!doVerify)
 	{
-		*theProcess << "-n";
+		*theProcess << QLatin1String( "-n" );
 	}
 
 #ifdef ANY_BSD
 	*theProcess
-		<< "-y"
-		<< "-f"
+		<< QLatin1String( "-y" )
+		<< QLatin1String( "-f" )
 		<< QString::number(deviceInfo->blocks) ;
 #elif defined(ANY_LINUX)
 	// No Linux-specific flags
@@ -480,7 +480,7 @@ void FDFormat::processStdOut(K3Process *, char *b, int l)
 	else
 	{
 		s = QString::fromLatin1(b,l);
-		if (s.contains("ioctl(FD_FORM)"))
+		if (s.contains(QLatin1String( "ioctl(FD_FORM)" )))
 		{
                     emit status (i18n(
                             "Cannot access floppy or floppy drive.\n"
@@ -488,7 +488,7 @@ void FDFormat::processStdOut(K3Process *, char *b, int l)
                             "have selected a valid floppy drive."),-1);
                     return;
 		}
-		if (s.indexOf("/dev/")>=0)
+		if (s.indexOf(QLatin1String( "/dev/" ))>=0)
 		{
 			emit status(s,-1);
 			return;
@@ -498,8 +498,8 @@ void FDFormat::processStdOut(K3Process *, char *b, int l)
 #elif defined(ANY_LINUX)
 	s = QString::fromLatin1(b,l);
 	DEBUGS(s);
-        QRegExp regexp( "([0-9]+)" );
-        if ( s.startsWith( "bad data at cyl" ) || s.contains( "Problem reading cylinder" ) )
+        QRegExp regexp( QLatin1String( "([0-9]+)" ) );
+        if ( s.startsWith( QLatin1String( "bad data at cyl" ) ) || s.contains( QLatin1String( "Problem reading cylinder" ) ) )
         {
             if ( regexp.indexIn( s ) > -1 )
             {
@@ -513,7 +513,7 @@ void FDFormat::processStdOut(K3Process *, char *b, int l)
             }
             return;
         }
-	else if (s.contains("ioctl(FDFMTBEG)"))
+	else if (s.contains(QLatin1String( "ioctl(FDFMTBEG)" )))
 	{
             emit status (i18n(
                     "Cannot access floppy or floppy drive.\n"
@@ -521,13 +521,13 @@ void FDFormat::processStdOut(K3Process *, char *b, int l)
                     "have selected a valid floppy drive."),-1);
             return;
 	}
-        else if (s.contains("busy")) // "Device or resource busy"
+        else if (s.contains(QLatin1String( "busy" ))) // "Device or resource busy"
         {
             emit status(i18n("Device busy.\nPerhaps you need to unmount the floppy first."),-1);
             return;
         }
         // Be careful to leave "iotcl" as last before checking numbers
-        else if (s.contains("ioctl"))
+        else if (s.contains(QLatin1String( "ioctl" )))
         {
             emit status(i18n("Low-level format error: %1", s),-1);
             return;
@@ -555,12 +555,12 @@ DDZeroOut::DDZeroOut(QObject *p) :
 {
     kDebug(KFAREA) << k_funcinfo ;
     theProcessName = QString::fromLatin1("dd");
-    setObjectName("DD");
+    setObjectName( QLatin1String("DD" ));
 }
 
 /* static */ bool DDZeroOut::runtimeCheck()
 {
-    m_ddName = findExecutable("dd");
+    m_ddName = findExecutable(QLatin1String( "dd" ));
     return (!m_ddName.isEmpty());
 }
 
@@ -587,8 +587,8 @@ DDZeroOut::DDZeroOut(QObject *p) :
 
     *theProcess << m_ddName ;
 
-    *theProcess << "if=/dev/zero" ;
-    *theProcess << "of="+deviceName;
+    *theProcess << QLatin1String( "if=/dev/zero" ) ;
+    *theProcess << QLatin1String( "of=" )+deviceName;
 
     if ( !startProcess() )
     {
@@ -627,7 +627,7 @@ FATFilesystem::FATFilesystem(QObject *parent) :
 	DEBUGSETUP;
 	runtimeCheck();
 	theProcessName=newfs_fat;
-	setObjectName("FATFilesystem");
+	setObjectName( QLatin1String("FATFilesystem" ));
 }
 
 /* static */ bool FATFilesystem::runtimeCheck()
@@ -635,9 +635,9 @@ FATFilesystem::FATFilesystem(QObject *parent) :
 	DEBUGSETUP;
 
 #ifdef ANY_BSD
-	newfs_fat = findExecutable("newfs_msdos");
+	newfs_fat = findExecutable(QLatin1String( "newfs_msdos" ));
 #elif defined(ANY_LINUX)
-	newfs_fat = findExecutable("mkdosfs");
+	newfs_fat = findExecutable(QLatin1String( "mkdosfs" ));
 #else
 	return false;
 #endif
@@ -679,25 +679,25 @@ void FATFilesystem::exec()
 		return;
 	}
 
-	if (theProcess) delete theProcess;
+	delete theProcess;
 	K3Process *p = theProcess = new K3Process;
 
 	*p << newfs_fat;
 #ifdef ANY_BSD
-	*p << "-f" << QString::number(deviceInfo->blocks);
+	*p << QLatin1String( "-f" ) << QString::number(deviceInfo->blocks);
 	if (doLabel)
 	{
-		*p << "-L" << label ;
+		*p << QLatin1String( "-L" ) << label ;
 	}
 #else
 #ifdef ANY_LINUX
 	if (doLabel)
 	{
-		*p << "-n" << label ;
+		*p << QLatin1String( "-n" ) << label ;
 	}
 	if (doVerify)
 	{
-		*p << "-c";
+		*p << QLatin1String( "-c" );
 	}
 #endif
 #endif
@@ -717,12 +717,12 @@ void FATFilesystem::processStdOut(K3Process *, char *b, int l)
 #elif defined(ANY_LINUX)
     QString s ( QString::fromLatin1( b, l ) );
     kDebug(KFAREA) << s ;
-    if (s.contains("mounted file system")) // "/dev/fd0 contains a mounted file system
+    if (s.contains(QLatin1String( "mounted file system" ))) // "/dev/fd0 contains a mounted file system
     {
         emit status(i18n("Floppy is mounted.\nYou need to unmount the floppy first."),-1);
         return;
     }
-    else if (s.contains("busy")) // "Device or resource busy"
+    else if (s.contains(QLatin1String( "busy" ))) // "Device or resource busy"
     {
         emit status(i18n("Device busy.\nPerhaps you need to unmount the floppy first."),-1);
         return;
@@ -748,14 +748,14 @@ UFSFilesystem::UFSFilesystem(QObject *parent) :
 	DEBUGSETUP;
 	runtimeCheck();
 	theProcessName=newfs;
-	setObjectName("UFSFilesystem");
+	setObjectName( QLatin1String("UFSFilesystem" ));
 }
 
 /* static */ bool UFSFilesystem::runtimeCheck()
 {
 	DEBUGSETUP;
 
-	newfs = findExecutable("newfs");
+	newfs = findExecutable(QLatin1String( "newfs" ));
 
 	return !newfs.isEmpty();
 }
@@ -778,7 +778,7 @@ void UFSFilesystem::exec()
 		return;
 	}
 
-	if (theProcess) delete theProcess;
+	delete theProcess;
 	K3Process *p = theProcess = new K3Process;
 
 	*p << newfs;
@@ -805,15 +805,15 @@ Ext2Filesystem::Ext2Filesystem(QObject *parent) :
 {
 	DEBUGSETUP;
 	runtimeCheck();
-	theProcessName="mke2fs";
-	setObjectName("Ext2Filesystem");
+	theProcessName=QLatin1String( "mke2fs" );
+	setObjectName( QLatin1String("Ext2Filesystem" ));
 }
 
 /* static */ bool Ext2Filesystem::runtimeCheck()
 {
 	DEBUGSETUP;
 
-	newfs = findExecutable("mke2fs");
+	newfs = findExecutable(QLatin1String( "mke2fs" ));
 
 	return !newfs.isEmpty();
 }
@@ -856,13 +856,13 @@ void Ext2Filesystem::exec()
 		return;
 	}
 
-	if (theProcess) delete theProcess;
+	delete theProcess;
 	K3Process *p = theProcess = new K3Process;
 
 	*p << newfs;
 	*p << "-q";
-	if (doVerify) *p << "-c" ;
-	if (doLabel) *p << "-L" << label ;
+	if (doVerify) *p << QLatin1String( "-c" ) ;
+	if (doLabel) *p << QLatin1String( "-L" ) << label ;
 
 	*p << deviceName ;
 
@@ -880,12 +880,12 @@ void Ext2Filesystem::processStdOut(K3Process *, char *b, int l)
 #elif defined(ANY_LINUX)
     QString s ( QString::fromLatin1( b, l ) );
     kDebug(KFAREA) << s ;
-    if (s.contains("mounted")) // "/dev/fd0 is mounted; will not make a filesystem here!"
+    if (s.contains(QLatin1String( "mounted" ))) // "/dev/fd0 is mounted; will not make a filesystem here!"
     {
         emit status(i18n("Floppy is mounted.\nYou need to unmount the floppy first."),-1);
         return;
     }
-    else if (s.contains("busy")) // "Device or resource busy"
+    else if (s.contains(QLatin1String( "busy" ))) // "Device or resource busy"
     {
         emit status(i18n("Device busy.\nPerhaps you need to unmount the floppy first."),-1);
         return;
@@ -903,15 +903,15 @@ MinixFilesystem::MinixFilesystem(QObject *parent) :
 {
 	DEBUGSETUP;
 	runtimeCheck();
-	theProcessName="mkfs.minix";
-	setObjectName("Minix2Filesystem");
+	theProcessName=QLatin1String( "mkfs.minix" );
+	setObjectName( QLatin1String("Minix2Filesystem" ));
 }
 
 /* static */ bool MinixFilesystem::runtimeCheck()
 {
 	DEBUGSETUP;
 
-	newfs = findExecutable("mkfs.minix");
+	newfs = findExecutable(QLatin1String( "mkfs.minix" ));
 
 	return !newfs.isEmpty();
 }
@@ -950,13 +950,13 @@ void MinixFilesystem::exec()
 		return;
 	}
 
-	if (theProcess) delete theProcess;
+	delete theProcess;
 	K3Process *p = theProcess = new K3Process;
 
 	*p << newfs;
 
         // Labeling is not possible
-	if (doVerify) *p << "-c" ;
+	if (doVerify) *p << QLatin1String( "-c" ) ;
 
 	*p << deviceName ;
 
@@ -971,12 +971,12 @@ void MinixFilesystem::processStdOut(K3Process *, char *b, int l)
 {
     QString s ( QString::fromLatin1( b, l ) );
     kDebug(KFAREA) << s ;
-    if (s.contains("mounted")) // "mkfs.minix: /dev/fd0 is mounted; will not make a filesystem here!"
+    if (s.contains(QLatin1String( "mounted" ))) // "mkfs.minix: /dev/fd0 is mounted; will not make a filesystem here!"
     {
         emit status(i18n("Floppy is mounted.\nYou need to unmount the floppy first."),-1);
         return;
     }
-    else if (s.contains("busy")) // "Device or resource busy"
+    else if (s.contains(QLatin1String( "busy" ))) // "Device or resource busy"
     {
         emit status(i18n("Device busy.\nPerhaps you need to unmount the floppy first."),-1);
         return;
