@@ -25,7 +25,6 @@ class KToggleAction;
 class KAction;
 class KFind;
 
-class KgpgInterface;
 class KgpgTextEdit;
 class KGpgItemModel;
 class KgpgLibrary;
@@ -96,11 +95,12 @@ private slots:
     // Signing menu
     void slotPreSignFile();
     void slotSignFile(const KUrl &url);
-    void slotSignFileFin(KgpgInterface *interface);
+    void slotSignFileFin();
     void slotPreVerifyFile();
     void slotVerifyFile(const KUrl &url);
     void slotCheckMd5();
     void importSignatureKey(const QString &id);
+    void slotVerifyFinished();
 
     // Options menu
     void slotOptions();
@@ -114,6 +114,10 @@ private slots:
 
     void slotRefreshImported(KgpgLibrary *lib, const QStringList &keys);
 
+    void slotLibraryDone();
+
+    void slotDownloadKeysFinished(QStringList ids);
+
 private:
     QStringList m_customdecrypt;
     QString m_textencoding;
